==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Navigation/DefaultNavigation/ts/DefaultNavigation_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>DefaultNavigation</name>
    <message>
        <location filename="../DefaultNavigation.js" line="+46"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Navigation</source>
        <translatorcomment>--google--
Navegación de mapas
Las capas ráster de elevada resolución pueden ralentizar la navegación en QGIS.
Las capas ráster de elevada resolución pueden ralentizar la navegación en QGIS</translatorcomment>
        <translation>Navegación</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Zoom (Wheel Mouse)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zoom (rueda del ratón)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Scroll (Trackpad, Multi-Touch Mouse)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Desplazamiento (Trackpad, Multi-Touch Mouse)</translation>
    </message>
</context>
<context>
    <name>GraphicsViewNavigation</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Mouse wheel / two finger swipe:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>La rueda del ratón / dos pasar el dedo:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Enable pan gesture</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Habilitar gesto de pan</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Reverse mouse wheel direction for zoom</source>
        <translation>Inversa dirección de la rueda del ratón para el zoom</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Mouse wheel zoom factor:</source>
        <translation>La rueda del ratón factor de zoom:</translation>
    </message>
    <message>
        <location line="-34"/>
        <source>Limit zoom and scroll to prevent overflows</source>
        <translation>Limitar el zoom para evitar desbordamientos</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Navigation/DefaultNavigation/ts/DefaultNavigation_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>DefaultNavigation</name>
    <message>
        <location filename="../DefaultNavigation.js" line="+47"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Navigation</source>
        <translatorcomment>--google--
Navegación de mapas
Las capas ráster de elevada resolución pueden ralentizar la navegación en QGIS.
Las capas ráster de elevada resolución pueden ralentizar la navegación en QGIS</translatorcomment>
        <translation>Navegación</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Zoom (Wheel Mouse)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zoom (rueda del ratón)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Scroll (Trackpad, Multi-Touch Mouse)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Desplazamiento (Trackpad, Multi-Touch Mouse)</translation>
    </message>
</context>
<context>
    <name>GraphicsViewNavigation</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Mouse wheel / two finger swipe:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>La rueda del ratón / dos pasar el dedo:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Enable pan gesture</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Habilitar gesto de pan</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Reverse mouse wheel direction for zoom</source>
        <translation>Inversa dirección de la rueda del ratón para el zoom</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Middle mouse button zoom factor:</source>
        <translation>Factor de zoom del botón central del ratón:</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Mouse wheel zoom factor:</source>
        <translation>La rueda del ratón factor de zoom:</translation>
    </message>
    <message>
        <location line="+207"/>
        <source>Panning threshold (px):</source>
        <translation>Umbral de panoramización:</translation>
    </message>
    <message>
        <location line="-217"/>
        <source>Limit zoom and scroll to prevent overflows</source>
        <translation>Limitar el zoom para evitar desbordamientos</translation>
    </message>
</context>
</TS>
